CtAssignSlice

Trait CtAssignSlice 

pub trait CtAssignSlice: CtAssign + Sized {
    // Provided method
    fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice) { ... }
}
Implementing this trait enables use of the CtAssign trait for [T] where T is the Self type implementing the trait, via a blanket impl.

It needs to be a separate trait from CtAssign because we need to be able to impl CtAssign for [T] which is ?Sized.

Provided Methods

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Conditionally assign src to dst if choice is Choice::TRUE, or leave it unchanged for Choice::FALSE.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl CtAssignSlice for Ordering

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for i8

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for i16

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for i32

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for i64

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for i128

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for isize

Source

impl CtAssignSlice for u8

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for u16

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for u32

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for u64

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for u128

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for usize

Source

impl CtAssignSlice for NonZeroI8

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for NonZeroI16

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for NonZeroI32

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for NonZeroI64

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for NonZeroI128

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for NonZeroU8

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for NonZeroU16

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for NonZeroU32

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for NonZeroU64

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl CtAssignSlice for NonZeroU128

Source

fn ct_assign_slice(dst: &mut [Self], src: &[Self], choice: Choice)

Source

impl<T, const N: usize> CtAssignSlice for [T; N]
where T: CtAssignSlice,

Implementors